[![PyPI](https://badgen.net/pypi/v/DiadFit)](https://pypi.org/project/DiadFit/)
[![Build Status](https://github.com/PennyWieser/DiadFit/actions/workflows/main.yml/badge.svg?branch=main)](https://github.com/PennyWieser/DiadFit/actions/workflows/main.yml)
[![codecov](https://codecov.io/gh/PennyWieser/DiadFit/branch/main/graph/badge.svg)](https://codecov.io/gh/PennyWieser/DiadFit/branch/main)

DiadFit is a python tool for fitting Raman data, particularly focused around applications to melt and fluid inclusions.

For more information and worked examples, please see https://diadfit.readthedocs.io/
